==> vite-plugin-proxy-0.4.2.tgz: package/src/middlewares/manifest.js <==
import parseurl from 'parseurl'
import * as proxy from '../proxy.js'
import { HttpError } from 'http-errors'
import logger from '../logger.js'
import finalhandler from 'finalhandler'

function mergeManifests (manifests) {
  const manifestsByHash = {}

  manifests.forEach(manifest => {
    const hash = `${manifest.namespace}--${manifest.path}`
    // overwrites existing ones. last wins
    manifestsByHash[hash] = manifest
  })
  return Object.values(manifestsByHash)
}

export default function ({ frontends }) {
  return async function (req, res, next) {
    if (req.headers['proxied-by-ox-proxy']) return next()
    const { path } = parseurl(req)
    if (path !== '/manifests') return next()

    try {
      logger.info(`Fetch manifests from "${frontends.map(f => f.target).join(', ')}"`)
      const responses = await proxy.all(req, res, frontends.map(({ target, secure }) => ({ url: target, headers: { 'proxied-by-ox-proxy': true }, secure })))
      const data = mergeManifests(responses.flat().reverse())
      logger.info('Merged manifests')

      // merge all manifests
      res.statusCode = 200
      res.setHeader('Content-Type', 'application/json')
      res.write(JSON.stringify(data))
      return res.end()
    } catch (err) {
      const handle = finalhandler(req, res)
      if (err instanceof HttpError) {
        // in case of http-error the proxy explicitedly received a error code
        logger.error(err)
        return handle(err)
      }
      logger.error(err)
      return handle()
    }
  }
}

==> vite-plugin-proxy-0.4.3.tgz: package/src/middlewares/manifest.js <==
import parseurl from 'parseurl'
import * as proxy from '../proxy.js'
import { HttpError } from 'http-errors'
import logger from '../logger.js'
import finalhandler from 'finalhandler'
import path from 'path'

function mergeManifests (manifests) {
  const manifestsByHash = {}

  manifests.forEach(manifest => {
    const hash = `${manifest.namespace}--${manifest.path}`
    // overwrites existing ones. last wins
    manifestsByHash[hash] = manifest
  })
  return Object.values(manifestsByHash)
}

export default function ({ base, frontends }) {
  const manifestsPath = path.join(base, '/manifests')
  return async function (req, res, next) {
    if (req.headers['proxied-by-ox-proxy']) return next()
    const { path } = parseurl(req)
    if (path !== manifestsPath) return next()

    try {
      logger.info(`Fetch manifests from "${frontends.map(f => f.target).join(', ')}"`)
      const responses = await proxy.all(req, res, frontends.map(({ target, secure }) => ({ url: target, headers: { 'proxied-by-ox-proxy': true }, secure })))
      const data = mergeManifests(responses.flat().reverse())
      logger.info('Merged manifests')

      // merge all manifests
      res.statusCode = 200
      res.setHeader('Content-Type', 'application/json')
      res.write(JSON.stringify(data))
      return res.end()
    } catch (err) {
      const handle = finalhandler(req, res)
      if (err instanceof HttpError) {
        // in case of http-error the proxy explicitedly received a error code
        logger.error(`Could not fetch manifests: ${err}`)
        return handle(err)
      }
      logger.error(err)
      return handle()
    }
  }
}
